<img src="quartet.png" width="100%">

# app: Adaptive Pressure Profile (APP) Shock Train Tracking

The APP method is an approach to adaptive realtime shock train tracking from pressure transducer data. 

## Software

The *python package* is available on pypi [here](https://pypi.org/project/app-stle/)

## Vignettes

A basic vignette of how to use APP is available [here](simple_example/simple_example.md) ([.py](simple_example/simple_example.py)  [.ipynb](simple_example/simple_example.ipynb))

## Papers

## 1. "Adaptive Pressure Profile Method to Locate the Isolator Shock Train Leading Edge Given Limited Pressure Information" AIAA 2020 P&E

- Our *publication* in AIAA P&E is available [here](https://arc.aiaa.org/doi/abs/10.2514/6.2020-3715)


